#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.1
visibility:           public
id:                   topograph-1.0.0.1-79K5zMXjtxEp3sfWGV9fO
key:                  topograph-1.0.0.1-79K5zMXjtxEp3sfWGV9fO
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  c4480f0a715603ab8ef75e299bffdd5d
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-8.10.5/site-local/topograph-1.0.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/topograph-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/topograph-1.0.0.1
hs-libraries:         HStopograph-1.0.0.1-79K5zMXjtxEp3sfWGV9fO
depends:
    base-4.14.2.0 base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    base-orphans-0.8.4-B4zsXTdczgN9mmNUwgnmE3 containers-0.6.4.1
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

